@@ -1,19 +1,18 @@
 import os
 import sys
+from .templates import main, index, css
+import spinne
 
 def main(name):
     print("Creating app...")
     if not os.path.exists(name):
         os.mkdir(name)
     with open(f"{name}/main.py", "w") as f:
-        f.write(open("templates/main.py", "r").read())
+        f.write(main.main)
         print("created main file...")
     with open(f"{name}/index.py", "w") as f:
-        f.write(open("templates/index.py", "r").read())
+        f.write(index.index)
         print("created index...")
-    with open(f"{name}/index.css", "w") as f:
-        f.write(open("templates/index.css", "r").read())
-        print("created index.css...")
 
 try:
     if sys.argv[1] == "--new" or "-n":
